summaryrefslogtreecommitdiff
path: root/include/apr_hash.h
diff options
context:
space:
mode:
authorwrowe <wrowe@13f79535-47bb-0310-9956-ffa450edef68>2001-05-16 05:30:52 +0000
committerwrowe <wrowe@13f79535-47bb-0310-9956-ffa450edef68>2001-05-16 05:30:52 +0000
commit22c3e557283950e9ba8afb403c83e93dbeab6a3b (patch)
tree9b5c141c29ce4f9039ae69d5f41e3df5647d75f3 /include/apr_hash.h
parent55f05d65e92ff3f1e83b9e5af5b9bb6a0a888db5 (diff)
downloadlibapr-22c3e557283950e9ba8afb403c83e93dbeab6a3b.tar.gz
Sing, "we are apr"... and make all hash functions accept apr_ssize_t
if we are going to bury -1 flags (I'd prefer the flag cast to apr_size_t and use that value throughout the hash api, however.) git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@61649 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/apr_hash.h')
-rw-r--r--include/apr_hash.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/apr_hash.h b/include/apr_hash.h
index c17a20851..4548905eb 100644
--- a/include/apr_hash.h
+++ b/include/apr_hash.h
@@ -119,7 +119,7 @@ APR_DECLARE(void) apr_hash_set(apr_hash_t *ht, const void *key,
* @param key Pointer to the key
* @param klen Length of the key. Can be APR_HASH_KEY_STRING to use the string length.
* @return Returns NULL if the key is not present.
* @deffunc void *apr_hash_get(apr_hash_t *ht, const void *key, apr_size_t klen)
*/
APR_DECLARE(void *) apr_hash_get(apr_hash_t *ht, const void *key,
apr_ssize_t klen);
@@ -168,10 +168,10 @@ APR_DECLARE(apr_hash_index_t *) apr_hash_next(apr_hash_index_t *hi);
* @param val Return pointer for the associated value.
* @tip The return pointers should point to a variable that will be set to the
* corresponding data, or they may be NULL if the data isn't interesting.
- * @deffunc void apr_hash_this(apr_hash_index_t *hi, const void **key, apr_size_t *klen, void **val);
+ * @deffunc void apr_hash_this(apr_hash_index_t *hi, const void **key, apr_ssize_t *klen, void **val);
*/
APR_DECLARE(void) apr_hash_this(apr_hash_index_t *hi, const void **key,
- apr_size_t *klen, void **val);
+ apr_ssize_t *klen, void **val);
/**
* Get the number of key/value pairs in the hash table.
@@ -119,7 +119,7 @@ APR_DECLARE(void) apr_hash_set(apr_hash_t *ht, const void *key,
* @param klen Length of the key. Can be APR_HASH_KEY_STRING to use the string length.
* @return Returns NULL if the key is not present.
- * @deffunc void *apr_hash_get(apr_hash_t *ht, const void *key, apr_size_t klen)
+ * @deffunc void *apr_hash_get(apr_hash_t *ht, const void *key, apr_ssize_t klen)
*/
APR_DECLARE(void *) apr_hash_get(apr_hash_t *ht, const void *key,